## 港股通每月成交统计

接口：ggt_monthly

描述：港股通每月成交信息，数据从2014年开始

限量：单次最大1000

积分：用户积5000积分可调取，请自行提高积分，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| month | str | N | 月度（格式YYYYMM，下同，支持多个输入） |
| start_month | str | N | 开始月度 |
| end_month | str | N | 结束月度 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| month | str | Y | 交易日期 |
| day_buy_amt | float | Y | 当月日均买入成交金额（亿元） |
| day_buy_vol | float | Y | 当月日均买入成交笔数（万笔） |
| day_sell_amt | float | Y | 当月日均卖出成交金额（亿元） |
| day_sell_vol | float | Y | 当月日均卖出成交笔数（万笔） |
| total_buy_amt | float | Y | 总买入成交金额（亿元） |
| total_buy_vol | float | Y | 总买入成交笔数（万笔） |
| total_sell_amt | float | Y | 总卖出成交金额（亿元） |
| total_sell_vol | float | Y | 总卖出成交笔数（万笔） |

接口示例

```python
pro = ts.pro_api()

#获取单月全部统计
df = pro.ggt_monthly(trade_date='201906')

#获取多月统计信息
df = pro.ggt_monthly(trade_date='201906,201907,201709')

#获取时间段统计信息
df = pro.ggt_monthly(start_date='201809', end_date='201908')
```

数据示例

```python
month  day_buy_amt  ...  total_sell_amt  total_sell_vol
0   201908        37.77  ...          450.97           96.62
```